==> edge-login-ui-rn-0.6.9.tgz: package/src/common/locales/strings.js <==
// @flow

import DeviceInfo from 'react-native-device-info'

import en from './en_US.js'
import es from './strings/es.json'
import fr from './strings/fr.json'
import it from './strings/it.json'
import ja from './strings/ja.json'
import ko from './strings/ko.json'
import pt from './strings/pt.json'
import ru from './strings/ru.json'
import vi from './strings/vi.json'
import zh from './strings/zh.json'

const allLocales = { en, ru, es, it, pt, ja, fr, ko, vi, zh }

const strings: { [stringCode: string]: string } = {}
const out = { strings }

selectLocale(DeviceInfo.getDeviceLocale())

function mergeStrings(primary: Object, secondary: Object) {
  for (const str of Object.keys(secondary)) {
    if (secondary[str]) {
      primary[str] = secondary[str]
    }
  }
}

// Locale formats can be in the form 'en', 'en-US', 'en_US', or 'enUS'
export function selectLocale(locale: string = 'en'): boolean {
  // Break up local into language and region
  const normalizedLocale = locale
    .replace('-', '')
    .replace('-', '')
    .replace('_', '')

  let found = false
  const lang = normalizedLocale.slice(0, 2)

  // Set default of US English
  mergeStrings(out.strings, en)

  if (locale === 'en') return true

  // Find pure language match first (ie. find 'es' when 'esMX' is chosen)
  if (allLocales[lang] !== undefined) {
    found = true
    mergeStrings(out.strings, allLocales[lang])
  }

  // Find an exact match
  if (allLocales[normalizedLocale] !== undefined) {
    found = true
    mergeStrings(out.strings, allLocales[normalizedLocale])
  }

  return found
}

export default out

==> edge-login-ui-rn-0.6.24.tgz: package/src/common/locales/strings.js <==
// @flow

import DeviceInfo from 'react-native-device-info'

import en from './en_US.js'
import es from './strings/es.json'
import fr from './strings/fr.json'
import it from './strings/it.json'
import ja from './strings/ja.json'
import ko from './strings/ko.json'
import pt from './strings/pt.json'
import ru from './strings/ru.json'
import vi from './strings/vi.json'
import zh from './strings/zh.json'

const allLocales = { en, ru, es, it, pt, ja, fr, ko, vi, zh }

const strings: typeof en = { ...en }
const out = { strings }

selectLocale(DeviceInfo.getDeviceLocale())

function mergeStrings(primary: Object, secondary: Object) {
  for (const str of Object.keys(secondary)) {
    if (secondary[str]) {
      primary[str] = secondary[str]
    }
  }
}

// Locale formats can be in the form 'en', 'en-US', 'en_US', or 'enUS'
export function selectLocale(locale: string = 'en'): boolean {
  // Break up local into language and region
  const normalizedLocale = locale
    .replace('-', '')
    .replace('-', '')
    .replace('_', '')

  let found = false
  const lang = normalizedLocale.slice(0, 2)

  // Set default of US English
  mergeStrings(out.strings, en)

  if (locale === 'en') return true

  // Find pure language match first (ie. find 'es' when 'esMX' is chosen)
  if (allLocales[lang] !== undefined) {
    found = true
    mergeStrings(out.strings, allLocales[lang])
  }

  // Find an exact match
  if (allLocales[normalizedLocale] !== undefined) {
    found = true
    mergeStrings(out.strings, allLocales[normalizedLocale])
  }

  return found
}

export default out
